"""The logless module: do more with (log)less."""

from .main import logged, logged_block, get_logger, flush_buffers

__all__ = [
    "logged",
    "logged_block",
    "get_logger",
    "flush_buffers",
]
